@@ -68,7 +68,7 @@ def run_webpack():
 # Provide access to the Selenium module fixture, for tests with specific needs.
 @pytest.fixture(scope="module")
 def selenium_module_fixture(request):
-    # Allow modules to specify the ``exit_status_success`` parameter passed to the ``ModuleFixture``` constructor by adding the statement ``pytestmark = pytest.mark.exit_status_success(False)``. (Since this is a module-scoped fixture, applying this mark to an individual test has no effect. Marking it True instead is equivalent to the unmarked, default value.) See the `example <https://docs.pytest.org/en/stable/fixture.html#using-markers-to-pass-data-to-fixtures>`_ (which applies only to function-scoped marks, not module-scoped marks), `marking whole classes or modules <https://docs.pytest.org/en/6.2.x/example/markers.html#marking-whole-classes-or-modules>`_, and the `API docs <https://docs.pytest.org/en/stable/reference.html#pytest.nodes.Node.get_closest_marker>`_.
+    # Allow modules to specify the ``exit_status_success`` parameter passed to the ``ModuleFixture`` constructor by adding the statement ``pytestmark = pytest.mark.exit_status_success(False)``. (Since this is a module-scoped fixture, applying this mark to an individual test has no effect. Marking it True instead is equivalent to the unmarked, default value.) See the `example <https://docs.pytest.org/en/stable/fixture.html#using-markers-to-pass-data-to-fixtures>`_ (which applies only to function-scoped marks, not module-scoped marks), `marking whole classes or modules <https://docs.pytest.org/en/6.2.x/example/markers.html#marking-whole-classes-or-modules>`_, and the `API docs <https://docs.pytest.org/en/stable/reference.html#pytest.nodes.Node.get_closest_marker>`_.
     exit_status_success_mark = request.node.get_closest_marker("exit_status_success")
     exit_status_success = True if exit_status_success_mark is None else exit_status_success_mark.args[0]
 
@@ -122,7 +122,7 @@ class ModuleFixture(unittest.TestCase):
         os.chdir(self.base_path)
         # Compile the docs. Save the stdout and stderr for examination.
         p = subprocess.run(
-            ["runestone", "build", "--all"], capture_output=True, text=True,
+            [sys.executable, "-m", "runestone", "build", "--all"], capture_output=True, text=True,
         )
         self.build_stdout_data = p.stdout
         self.build_stderr_data = p.stderr
@@ -184,9 +184,9 @@ class ModuleFixture(unittest.TestCase):
                         "Unknown error while trying to kill stale runestone server"
                     )
 
-        # Run the server. Simply calling ``runestone serve`` fails, since the process killed isn't the actual server, but probably a setuptools-created launcher.
+        # Run the server. Simply calling ``runestone preview`` fails, since the process killed isn't the actual server, but probably a setuptools-created launcher.
         self.runestone_server = subprocess.Popen(
-            [sys.executable, "-m", "runestone", "serve", "--port", PORT]
+            [sys.executable, "-m", "runestone", "preview", "--port", PORT]
         )
 
         # Testing time in dominated by browser startup/shutdown. So, simply run all tests in a module in a single browser instance to speed things up. See ``RunestoneTestCase.setUp`` for additional code to (mostly) clear the browser between tests.
